﻿using System;
using System.Windows;
using Shell.Views;
using Microsoft.Practices.Prism.MefExtensions;
using Microsoft.Practices.Prism.Modularity;
using System.ComponentModel.Composition.Hosting;

namespace Shell
{
	public class Bootstrapper : MefBootstrapper
	{
		protected override void InitializeShell()
		{
			base.InitializeShell();

			Application.Current.RootVisual = (UIElement)Shell;
		}

		protected override DependencyObject CreateShell()
		{
			return Container.GetExportedValue<ShellView>();
		}

		protected override void ConfigureAggregateCatalog()
		{
			base.ConfigureAggregateCatalog();

			// Prism's AggregateCatalog is a catalog of all MEF composable parts
			// within the application.
			// We add the parts corresponding to the current assembly to it
			AggregateCatalog.Catalogs.Add(new AssemblyCatalog(this.GetType().Assembly));
		}

		protected override IModuleCatalog CreateModuleCatalog()
		{
			ModuleCatalog moduleCatalog = new ModuleCatalog();

            // this is the code responsible 
            // for adding Module4 to the application
            moduleCatalog.AddModule
            (
                new ModuleInfo
                {
                    InitializationMode = InitializationMode.WhenAvailable,
                    Ref = "Module4.xap",
                    ModuleName = "Module4",
                    ModuleType = "Module4.Module4, Module4, Version=1.0.0.0, Culture=neutral, PublicKeyToken=null"
                }
            );

			// this is the code responsible 
			// for adding Module1 to the application
			moduleCatalog.AddModule
			(
				new ModuleInfo
				{
					InitializationMode = InitializationMode.WhenAvailable,
					Ref = "Module1.xap",
					ModuleName = "Module1",
					ModuleType = "Module1.Module1, Module1, Version=1.0.0.0, Culture=neutral, PublicKeyToken=null"
				}
			);


			// this is the code responsible 
			// for adding Module2 to the application
			moduleCatalog.AddModule
		 (
			 new ModuleInfo
			 {
				 InitializationMode = InitializationMode.WhenAvailable,
				 DependsOn = new System.Collections.ObjectModel.Collection<string> { "Module1" },
				 Ref = "Module2.xap",
				 ModuleName = "Module2",
				 ModuleType = "Module2.Module2, Module2, Version=1.0.0.0, Culture=neutral, PublicKeyToken=null"
			 }
		 );

			// this is the code responsible 
			// for adding Module3 to the application
			moduleCatalog.AddModule
		 (
			 new ModuleInfo
			 {
				 InitializationMode = InitializationMode.WhenAvailable,
				 DependsOn = new System.Collections.ObjectModel.Collection<string> { "Module2" },
				 Ref = "Module3.xap",
				 ModuleName = "Module3",
				 ModuleType = "Module3.Module3, Module3, Version=1.0.0.0, Culture=neutral, PublicKeyToken=null"
			 }
		 );
			return moduleCatalog;
		}
	}
}